@@ -224,11 +224,13 @@ extern "C" {
 #define R_SYS_DIR "\\"
 #define R_SYS_ENVSEP ";"
 #define R_SYS_HOME "USERPROFILE"
+#define R_SYS_TMP "TEMP"
 #else
 #define FS "/"
 #define R_SYS_DIR "/"
 #define R_SYS_ENVSEP ":"
 #define R_SYS_HOME "HOME"
+#define R_SYS_TMP "TMPDIR"
 #endif
 
 #define R_JOIN_2_PATHS(p1, p2) p1 R_SYS_DIR p2
@@ -557,7 +559,7 @@ enum {
 	R_SYS_ARCH_LM32 =  0x80000000LL, // 1<<31
 };
 
-#if CLOCK_MONOTONIC && (__linux__ || (__FreeBSD__ && __FreeBSD_version >= 1101000) || (__NetBSD__ && __NetBSD_Version__ >= 700000000))
+#if HAVE_CLOCK_NANOSLEEP && CLOCK_MONOTONIC && (__linux__ || (__FreeBSD__ && __FreeBSD_version >= 1101000) || (__NetBSD__ && __NetBSD_Version__ >= 700000000))
 #define HAS_CLOCK_NANOSLEEP 1
 #else
 #define HAS_CLOCK_NANOSLEEP 0
@@ -584,20 +586,6 @@ enum {
 #define R_SYS_OS "unknown"
 #endif
 
-#if __GNUC__
-#  define r_sys_trap() __builtin_trap()
-#else
-#  if __i386__ || __x86_64__
-#    define r_sys_trap() __asm__ __volatile__ ("int3")
-#  elif __arm__
-#    define r_sys_trap() __asm__ __volatile__ ("bkpt")
-#  elif __arm64__
-#    define r_sys_trap() __asm__ __volatile__ ("brk #1")
-#  else
-#    define r_sys_trap() __asm__ __volatile__ (".word 0");
-#  endif
-#endif
-
 #ifdef __cplusplus
 }
 #endif
@@ -652,4 +640,12 @@ static inline void r_run_call10(void *fcn, void *arg1, void *arg2, void *arg3, v
 		(arg1, arg2, arg3, arg4, arg5, arg6, arg7, arg8, arg9, arg10);
 }
 
+#ifndef container_of
+# ifdef _MSC_VER
+#  define container_of(ptr, type, member) ((type *)((char *)(ptr) - offsetof(type, member)))
+# else
+#  define container_of(ptr, type, member) ((type *)((char *)(__typeof__(((type *)0)->member) *){ptr} - offsetof(type, member)))
+# endif
+#endif
+
 #endif // R2_TYPES_H
