@@ -31,19 +31,22 @@ static inline void r_str_rmch(char *s, char ch) {
 #define r_str_array(x,y) ((y>=0 && y<(sizeof(x)/sizeof(*x)))?x[y]:"")
 R_API const char *r_str_pad(const char ch, int len);
 R_API const char *r_str_rstr(const char *base, const char *p);
+R_API const char *r_strstr_ansi (const char *a, const char *b);
 R_API const char *r_str_rchr(const char *base, const char *p, int ch);
 R_API const char *r_str_closer_chr(const char *b, const char *s);
 R_API int r_str_bounds(const char *str, int *h);
 R_API char *r_str_crop(const char *str, unsigned int x, unsigned int y, unsigned int x2, unsigned int y2);
 R_API bool r_str_range_in(const char *r, ut64 addr);
 R_API int r_str_len_utf8(const char *s);
+R_API int r_str_len_utf8_ansi(const char *str);
 R_API int r_str_len_utf8char(const char *s, int left);
 R_API void r_str_filter_zeroline(char *str, int len);
-R_API int r_str_utf8_codepoint (const char* s, int left);
-R_API bool r_str_char_fullwidth (const char* s, int left);
+R_API int r_str_utf8_codepoint(const char *s, int left);
+R_API bool r_str_char_fullwidth(const char *s, int left);
 R_API int r_str_write(int fd, const char *b);
-R_API void r_str_ncpy(char *dst, const char *src, int n);
+R_API void r_str_ncpy(char *dst, const char *src, size_t n);
 R_API void r_str_sanitize(char *c);
+R_API char *r_str_sanitize_sdb_key(const char *s);
 R_API const char *r_str_casestr(const char *a, const char *b);
 R_API const char *r_str_firstbut(const char *s, char ch, const char *but);
 R_API const char *r_str_lastbut(const char *s, char ch, const char *but);
@@ -51,6 +54,7 @@ R_API int r_str_split(char *str, char ch);
 R_API RList *r_str_split_list(char *str, const char *c);
 R_API int *r_str_split_lines(char *str, int *count);
 R_API char* r_str_replace(char *str, const char *key, const char *val, int g);
+R_API char *r_str_replace_icase(char *str, const char *key, const char *val, int g, int keep_case);
 R_API char *r_str_replace_in(char *str, ut32 sz, const char *key, const char *val, int g);
 #define r_str_cpy(x,y) memmove(x,y,strlen(y)+1);
 R_API int r_str_bits(char *strout, const ut8 *buf, int len, const char *bitz);
@@ -112,7 +116,6 @@ R_API const char *r_str_get(const char *str);
 R_API const char *r_str_get2(const char *str);
 R_API char *r_str_ndup(const char *ptr, int len);
 R_API char *r_str_dup(char *ptr, const char *string);
-R_API void *r_str_free(void *ptr);
 R_API int r_str_inject(char *begin, char *end, char *str, int maxlen);
 R_API int r_str_delta(char *p, char a, char b);
 R_API void r_str_filter(char *str, int len);
@@ -154,6 +157,7 @@ R_API int r_wstr_clen(const char *s);
 R_API char *r_str_prefix(char *ptr, const char *string);
 R_API char *r_str_prefix_all(const char *s, const char *pfx);
 R_API char *r_str_append(char *ptr, const char *string);
+R_API char *r_str_append_owned(char *ptr, char *string);
 R_API char *r_str_appendf(char *ptr, const char *fmt, ...);
 R_API char *r_str_appendch(char *x, char y);
 R_API void r_str_case(char *str, bool up);
@@ -173,6 +177,7 @@ R_API char* r_str_highlight(char *str, const char *word, const char *color, cons
 R_API char *r_qrcode_gen(const ut8 *text, int len, bool utf8, bool inverted);
 R_API char *r_str_from_ut64(ut64 val);
 R_API void r_str_stripLine(char *str, const char *key);
+R_API char *r_str_list_join(RList *str, const char *sep);
 #ifdef __cplusplus
 }
 #endif
